bayespy.inference.vmp.nodes.wishart.WishartMoments.add_converter
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartMoments.add_converter